@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 from collections.abc import Mapping
-from typing import TYPE_CHECKING
 
 from hypothesis import given
 from hypothesis.errors import InvalidArgument
@@ -20,9 +19,7 @@ from utilities.hypothesis import (
     str_data_arrays,
     text_ascii,
 )
-
-if TYPE_CHECKING:  # pragma: no cover
-    from utilities.pandas import IndexA
+from utilities.pandas import IndexA
 
 
 class TestBoolDataArrays:
