@@ -8,6 +8,7 @@ from hypothesis.strategies import booleans, floats, integers, none, text
 from pandas import read_pickle as _read_pickle
 
 from utilities.hypothesis import temp_paths
+from utilities.pathvalidate import valid_path
 from utilities.pickle import write_pickle
 
 
@@ -17,6 +18,6 @@ class TestReadAndWritePickle:
         root=temp_paths(),
     )
     def test_main(self, *, obj: Any, root: Path) -> None:
-        write_pickle(obj, path := root.joinpath("file"))
+        write_pickle(obj, path := valid_path(root, "file"))
         result = _read_pickle(path, compression="gzip")  # noqa: S301
         assert result == obj
