@@ -6,6 +6,7 @@ from pathlib import Path
 from click.testing import CliRunner
 from pytest import fixture
 
+from utilities.pathvalidate import valid_path
 from utilities.platform import IS_WINDOWS
 from utilities.scripts.csv_to_markdown import _csv_to_markdown, main
 from utilities.text import strip_and_dedent
@@ -13,7 +14,7 @@ from utilities.text import strip_and_dedent
 
 @fixture()
 def path_csv(*, tmp_path: Path) -> Path:
-    path = tmp_path.joinpath("input.csv")
+    path = valid_path(tmp_path, "input.csv")
     with path.open(mode="w", newline="" if IS_WINDOWS else None) as fh:
         csv_writer = writer(fh)
         csv_writer.writerow(["Foo", "Bar"])
