@@ -22,24 +22,69 @@ from hypothesis.strategies import (
     sampled_from,
     sets,
 )
-from polars import DataFrame, Datetime, Float64, Int64, PolarsDataType, Utf8
+from polars import (
+    Binary,
+    DataFrame,
+    Datetime,
+    Decimal,
+    Duration,
+    Float64,
+    Int64,
+    PolarsDataType,
+    Utf8,
+)
+from polars.datatypes import DataTypeClass
 from polars.testing import assert_frame_equal
 from pytest import mark, param, raises
 from sqlalchemy import (
+    BIGINT,
+    BINARY,
+    BOOLEAN,
+    CHAR,
+    CLOB,
+    DATE,
+    DATETIME,
+    DECIMAL,
+    DOUBLE,
+    DOUBLE_PRECISION,
+    FLOAT,
+    INT,
+    INTEGER,
+    NCHAR,
+    NUMERIC,
+    NVARCHAR,
+    REAL,
+    SMALLINT,
+    TEXT,
+    TIME,
+    TIMESTAMP,
+    UUID,
+    VARBINARY,
+    VARCHAR,
+    BigInteger,
     Column,
     DateTime,
+    Double,
     Engine,
     Float,
     Integer,
+    Interval,
     LargeBinary,
     MetaData,
+    Numeric,
     Select,
+    SmallInteger,
     String,
     Table,
+    Text,
+    Unicode,
+    UnicodeText,
+    Uuid,
     select,
 )
 from sqlalchemy.exc import DuplicateColumnError
 
+from utilities._sqlalchemy.common import ensure_tables_created
 from utilities._sqlalchemy.polars import (
     _insert_dataframe_map_df_column_to_table_column_and_type,
     _insert_dataframe_map_df_column_to_table_schema,
@@ -49,9 +94,8 @@ from utilities._sqlalchemy.polars import (
     _select_to_dataframe_apply_snake,
     _select_to_dataframe_check_duplicates,
     _select_to_dataframe_map_select_to_df_schema,
-    _select_to_dataframe_map_table_column_to_dtype,
+    _select_to_dataframe_map_table_column_type_to_dtype,
     _select_to_dataframe_yield_selects_with_in_clauses,
-    _SelectToDataFrameMapTableColumnToDTypeError,
 )
 from utilities.datetime import UTC, is_equal_mod_tz
 from utilities.hypothesis import sqlite_engines, text_ascii
@@ -310,7 +354,7 @@ class TestSelectToDataFrame:
         batch_size=integers(1, 10) | none(),
         in_clauses_chunk_size=integers(1, 10),
     )
-    def test_engine_and_in_clauses(
+    def test_engine_and_in_clauses_non_empty(
         self,
         *,
         data: DataObject,
@@ -339,6 +383,19 @@ class TestSelectToDataFrame:
         check_polars_dataframe(df, height=len(in_values), schema={"value": Int64})
         assert set(df["value"].to_list()) == in_values
 
+    @given(engine=sqlite_engines())
+    def test_engine_and_in_clauses_empty(self, *, engine: Engine) -> None:
+        table = Table(
+            "example",
+            MetaData(),
+            Column("id", Integer, primary_key=True),
+            Column("value", Integer),
+        )
+        ensure_tables_created(engine, table)
+        sel = select(table.c["value"])
+        df = select_to_dataframe(sel, engine, in_clauses=(table.c["value"], []))
+        check_polars_dataframe(df, height=0, schema={"value": Int64})
+
     @given(
         engine=sqlite_engines(),
         values=lists(booleans() | none(), max_size=100),
@@ -418,7 +475,7 @@ class TestSelectToDataFrame:
         table = Table("example", MetaData(), Column("id", Integer, primary_key=True))
         sel = select(table)
         with raises(SelectToDataFrameError):
-            _ = select_to_dataframe(sel, engine, batch_size=1)  # type: ignore
+            _ = select_to_dataframe(sel, engine, batch_size=1)
 
 
 class TestSelectToDataFrameApplySnake:
@@ -453,11 +510,65 @@ class TestSelectToDataFrameMapSelectToDFSchema:
         assert schema == expected
 
 
-class TestSelectToDataFrameMapTableColumnToDType:
-    def test_error(self) -> None:
-        column = Column("value", LargeBinary)
-        with raises(_SelectToDataFrameMapTableColumnToDTypeError):
-            _ = _select_to_dataframe_map_table_column_to_dtype(column)
+class TestSelectToDataFrameMapTableColumnTypeToDType:
+    @mark.parametrize(
+        ("col_type", "expected"),
+        [
+            param(BigInteger, Int64),
+            param(BIGINT, Int64),
+            param(BINARY, Binary),
+            param(sqlalchemy.Boolean, pl.Boolean),
+            param(BOOLEAN, pl.Boolean),
+            param(CHAR, Utf8),
+            param(CLOB, Utf8),
+            param(sqlalchemy.Date, pl.Date),
+            param(DATE, pl.Date),
+            param(DECIMAL, Decimal),
+            param(Double, Float64),
+            param(DOUBLE, Float64),
+            param(DOUBLE_PRECISION, Float64),
+            param(Float, Float64),
+            param(FLOAT, Float64),
+            param(INT, Int64),
+            param(Integer, Int64),
+            param(INTEGER, Int64),
+            param(Interval, Duration),
+            param(LargeBinary, Binary),
+            param(NCHAR, Utf8),
+            param(Numeric, Decimal),
+            param(NUMERIC, Decimal),
+            param(NVARCHAR, Utf8),
+            param(REAL, Float64),
+            param(SMALLINT, Int64),
+            param(SmallInteger, Int64),
+            param(String, Utf8),
+            param(TEXT, Utf8),
+            param(Text, Utf8),
+            param(TIME, pl.Time),
+            param(sqlalchemy.Time, pl.Time),
+            param(Unicode, Utf8),
+            param(UnicodeText, Utf8),
+            param(Uuid, pl.Utf8),
+            param(UUID, pl.Utf8),
+            param(VARBINARY, Binary),
+            param(VARCHAR, Utf8),
+        ],
+    )
+    @mark.parametrize("use_inst", [param(True), param(False)])
+    def test_main(
+        self, *, col_type: Any, use_inst: bool, expected: DataTypeClass
+    ) -> None:
+        col_type_use = col_type() if use_inst else col_type
+        dtype = _select_to_dataframe_map_table_column_type_to_dtype(col_type_use)
+        assert isinstance(dtype, type)
+        assert issubclass(dtype, expected)
+
+    @mark.parametrize("col_type", [param(DATETIME), param(DateTime), param(TIMESTAMP)])
+    @mark.parametrize("timezone", [param(None), param(True), param(False)])
+    def test_datetime(self, *, col_type: Any, timezone: bool | None) -> None:
+        col_type_use = col_type if timezone is None else col_type(timezone=timezone)
+        dtype = _select_to_dataframe_map_table_column_type_to_dtype(col_type_use)
+        assert isinstance(dtype, Datetime)
 
 
 class TestSelectToDataFrameYieldSelectsWithInClauses:
