@@ -81,7 +81,7 @@ from utilities.hypothesis import (
 from utilities.sqlalchemy import (
     CheckEngineError,
     ParseEngineError,
-    TableAlreadyExistsError,
+    TableDoesNotExistError,
     TablenameMixin,
     _check_column_collections_equal,
     _check_column_types_boolean_equal,
@@ -122,8 +122,7 @@ from utilities.sqlalchemy import (
     get_table_name,
     insert_items,
     parse_engine,
-    redirect_to_no_such_table_error,
-    redirect_to_table_already_exists_error,
+    redirect_table_does_not_exist,
     reflect_table,
     serialize_engine,
 )
@@ -605,42 +604,16 @@ class TestCheckEngine:
         check_engine(engine)
 
     @given(engine=sqlite_engines())
-    def test_num_tables(self, *, engine: Engine) -> None:
+    def test_num_tables_pass(self, *, engine: Engine) -> None:
         table = Table("example", MetaData(), Column("id", Integer, primary_key=True))
         ensure_tables_created(engine, table)
         check_engine(engine, num_tables=1)
 
     @given(engine=sqlite_engines())
-    def test_num_tables_rel_tol(self, *, engine: Engine) -> None:
-        table = Table("example", MetaData(), Column("id", Integer, primary_key=True))
-        ensure_tables_created(engine, table)
-        check_engine(engine, num_tables=2, rel_tol=0.5)
-
-    @given(engine=sqlite_engines())
-    def test_num_tables_abs_tol(self, *, engine: Engine) -> None:
-        check_engine(engine, num_tables=1, abs_tol=1)
-
-    @given(root=temp_paths())
-    def test_error_unable_to_open(self, *, root: Path) -> None:
-        engine = create_engine("sqlite", database=str(root))
-        with raises(CheckEngineError):
-            check_engine(engine)
-
-    @given(engine=sqlite_engines())
-    def test_error_num_tables_int(self, *, engine: Engine) -> None:
+    def test_num_tables_error(self, *, engine: Engine) -> None:
         with raises(CheckEngineError):
             check_engine(engine, num_tables=1)
 
-    @given(engine=sqlite_engines())
-    def test_error_num_tables_rel_tol(self, *, engine: Engine) -> None:
-        with raises(CheckEngineError):
-            check_engine(engine, num_tables=1, rel_tol=0.5)
-
-    @given(engine=sqlite_engines())
-    def test_error_num_tables_abs_tol(self, *, engine: Engine) -> None:
-        with raises(CheckEngineError):
-            check_engine(engine, num_tables=2, abs_tol=1)
-
 
 class TestCheckTableAgainstReflection:
     @given(engine=sqlite_engines())
@@ -719,7 +692,9 @@ class TestCheckTableOrColumnNamesEqual:
 class TestColumnwiseMinMax:
     @given(
         engine=sqlite_engines(),
-        values=sets(tuples(integers(0, 10) | none(), integers(0, 10) | none())),
+        values=sets(
+            tuples(integers(0, 10) | none(), integers(0, 10) | none()), min_size=1
+        ),
     )
     def test_main(
         self, *, engine: Engine, values: set[tuple[int | None, int | None]]
@@ -731,7 +706,6 @@ class TestColumnwiseMinMax:
             Column("x", Integer),
             Column("y", Integer),
         )
-        ensure_tables_created(engine, table)
         insert_items(engine, ([{"x": x, "y": y} for x, y in values], table))
         sel = select(
             table.c["x"],
@@ -796,38 +770,6 @@ class TestEnsureEngine:
         assert result.url == engine.url
 
 
-class TestEnsureTablesCreated:
-    @given(engine=sqlite_engines())
-    @mark.parametrize("runs", [param(1), param(2)])
-    def test_table(self, *, engine: Engine, runs: int) -> None:
-        table = Table("example", MetaData(), Column("id_", Integer, primary_key=True))
-        self._run_test(table, engine, runs)
-
-    @given(engine=sqlite_engines())
-    @mark.parametrize("runs", [param(1), param(2)])
-    def test_mapped_class(self, *, engine: Engine, runs: int) -> None:
-        class Example(declarative_base()):
-            __tablename__ = "example"
-
-            id_ = Column(Integer, primary_key=True)
-
-        self._run_test(Example, engine, runs)
-
-    def _run_test(
-        self, table_or_mapped_class: Table | type[Any], engine: Engine, runs: int, /
-    ) -> None:
-        sel = get_table(table_or_mapped_class).select()
-        with raises(NoSuchTableError), engine.begin() as conn:
-            try:
-                _ = conn.execute(sel).all()
-            except DatabaseError as error:
-                redirect_to_no_such_table_error(engine, error)
-        for _ in range(runs):
-            ensure_tables_created(engine, table_or_mapped_class)
-        with engine.begin() as conn:
-            _ = conn.execute(sel).all()
-
-
 class TestEnsureTablesDropped:
     @given(engine=sqlite_engines())
     @mark.parametrize("runs", [param(1), param(2)])
@@ -849,17 +791,13 @@ class TestEnsureTablesDropped:
         self, table_or_mapped_class: Table | type[Any], engine: Engine, runs: int, /
     ) -> None:
         table = get_table(table_or_mapped_class)
-        sel = table.select()
         with engine.begin() as conn:
             table.create(conn)
-            _ = conn.execute(sel).all()
         for _ in range(runs):
             ensure_tables_dropped(engine, table_or_mapped_class)
-        with raises(NoSuchTableError), engine.begin() as conn:
-            try:
-                _ = conn.execute(sel).all()
-            except DatabaseError as error:
-                redirect_to_no_such_table_error(engine, error)
+        sel = table.select()
+        with raises(DatabaseError), engine.begin() as conn:
+            _ = conn.execute(sel).all()
 
 
 class TestGetColumnNames:
@@ -917,28 +855,14 @@ class TestRedirectToNoSuchSequenceError:
             _ = conn.scalar(seq)
 
 
-class TestRedirectToNoSuchTableError:
+class TestRedirectTableDoesNotExist:
     @given(engine=sqlite_engines())
     def test_main(self, *, engine: Engine) -> None:
         table = Table("example", MetaData(), Column("id", Integer, primary_key=True))
-        with raises(NoSuchTableError), engine.begin() as conn:
-            try:
-                _ = conn.execute(select(table))
-            except DatabaseError as error:
-                redirect_to_no_such_table_error(engine, error)
-
-
-class TestRedirectToTableAlreadyExistsError:
-    @given(engine=sqlite_engines())
-    def test_main(self, *, engine: Engine) -> None:
-        table = Table("example", MetaData(), Column("id", Integer, primary_key=True))
-        with engine.begin() as conn:
-            _ = table.create(conn)
-        with raises(TableAlreadyExistsError), engine.begin() as conn:
-            try:
-                _ = table.create(conn)
-            except DatabaseError as error:
-                redirect_to_table_already_exists_error(engine, error)
+        with raises(TableDoesNotExistError), redirect_table_does_not_exist(
+            engine
+        ), engine.begin() as conn:
+            _ = conn.execute(select(table))
 
 
 class TestReflectTable:
