@@ -1,16 +1,18 @@
+from __future__ import annotations
+
 from os import getenv
 
 from hypothesis import given
 
 from utilities.hypothesis import text_ascii
-from utilities.os import CPU_COUNT, _get_cpu_count, temp_environ
+from utilities.os import CPU_COUNT, get_cpu_count, temp_environ
 
 text = text_ascii(min_size=1, max_size=10)
 
 
 class TestCPUCount:
     def test_function(self) -> None:
-        assert isinstance(_get_cpu_count(), int)
+        assert isinstance(get_cpu_count(), int)
 
     def test_constant(self) -> None:
         assert isinstance(CPU_COUNT, int)
@@ -22,14 +24,14 @@ def prefix(text: str, /) -> str:
 
 class TestTempEnviron:
     @given(key=text.map(prefix), value=text)
-    def test_set(self, key: str, value: str) -> None:
+    def test_set(self, *, key: str, value: str) -> None:
         assert getenv(key) is None
         with temp_environ({key: value}):
             assert getenv(key) == value
         assert getenv(key) is None
 
     @given(key=text.map(prefix), prev=text, new=text)
-    def test_override(self, key: str, prev: str, new: str) -> None:
+    def test_override(self, *, key: str, prev: str, new: str) -> None:
         with temp_environ({key: prev}):
             assert getenv(key) == prev
             with temp_environ({key: new}):
@@ -37,7 +39,7 @@ class TestTempEnviron:
             assert getenv(key) == prev
 
     @given(key=text.map(prefix), value=text)
-    def test_unset(self, key: str, value: str) -> None:
+    def test_unset(self, *, key: str, value: str) -> None:
         with temp_environ({key: value}):
             assert getenv(key) == value
             with temp_environ({key: None}):
