@@ -6,6 +6,7 @@ from subprocess import CalledProcessError, check_call
 
 from pytest import raises
 
+from utilities.pathvalidate import valid_path
 from utilities.pytest import skipif_windows
 from utilities.subprocess import (
     GetShellOutputError,
@@ -31,14 +32,14 @@ class TestGetShellOutput:
 
     @skipif_windows
     def test_activate(self, *, tmp_path: Path) -> None:
-        venv = tmp_path.joinpath(".venv")
-        activate = venv.joinpath("activate")
+        venv = valid_path(tmp_path, ".venv")
+        activate = valid_path(venv, "activate")
         activate.parent.mkdir(parents=True)
         activate.touch()
         _ = get_shell_output("ls", cwd=venv, activate=venv)
 
     def test_no_activate(self, *, tmp_path: Path) -> None:
-        venv = tmp_path.joinpath(".venv")
+        venv = valid_path(tmp_path, ".venv")
         with raises(GetShellOutputError):
             _ = get_shell_output("ls", cwd=venv, activate=venv)
 
