@@ -6,6 +6,7 @@ from numpy import array, nan
 from numpy.testing import assert_equal
 from zarr import open_array
 
+from utilities.pathvalidate import valid_path
 from utilities.zarr import ffill_non_nan_slices
 
 
@@ -14,7 +15,7 @@ class TestFFillNonNanSlices:
         arr = array(
             [[0.1, nan, nan, 0.2], 4 * [nan], [0.3, nan, nan, nan]], dtype=float
         )
-        z_arr = open_array(tmp_path.joinpath("array"), shape=arr.shape, dtype=float)
+        z_arr = open_array(valid_path(tmp_path, "array"), shape=arr.shape, dtype=float)
         z_arr[:] = arr
         ffill_non_nan_slices(z_arr)
         expected = array(
