@@ -1,12 +1,17 @@
 from __future__ import annotations
 
+from dataclasses import dataclass
+from typing import Any
+
 from holoviews import Curve
 from holoviews.plotting import bokeh
+from typing_extensions import override
 
 from utilities._holoviews.common import apply_opts
-from utilities.errors import redirect_error
+from utilities.iterables import _CheckLengthMinError, check_length
 from utilities.numpy import has_dtype
 from utilities.text import EnsureStrError, ensure_str
+from utilities.types import get_class_name
 from utilities.xarray import DataArrayB1, DataArrayF1, DataArrayI1
 
 _ = bokeh
@@ -24,11 +29,14 @@ def plot_curve(
     if has_dtype(array, bool):
         return plot_curve(array.astype(int), label=label, smooth=smooth, aspect=aspect)
     (kdim,) = array.dims
-    with redirect_error(EnsureStrError, PlotCurveError(f"{array.name=}")):
+    try:
         vdim = ensure_str(array.name)
-    if len(vdim) == 0:
-        msg = f"{array.name=}"
-        raise PlotCurveError(msg)
+    except EnsureStrError:
+        raise _PlotCurveArrayNameNotAStringError(name=array.name) from None
+    try:
+        _ = check_length(vdim, min=1)
+    except _CheckLengthMinError:
+        raise _PlotCurveArrayNameIsEmptyError(name=vdim) from None
     if label is None:
         label = vdim
     if smooth is not None:
@@ -47,4 +55,24 @@ class PlotCurveError(Exception):
     ...
 
 
+@dataclass(frozen=True, kw_only=True, slots=True)
+class _PlotCurveArrayNameNotAStringError(PlotCurveError):
+    name: Any
+
+    @override
+    def __str__(self) -> str:
+        return "Array name {} must be a string; got {!r} instead".format(
+            self.name, get_class_name(self.name)
+        )
+
+
+@dataclass(frozen=True, kw_only=True, slots=True)
+class _PlotCurveArrayNameIsEmptyError(PlotCurveError):
+    name: str
+
+    @override
+    def __str__(self) -> str:
+        return "Array name {!r} must not be empty".format(self.name)
+
+
 __all__ = ["PlotCurveError", "plot_curve"]
