@@ -33,9 +33,9 @@ from utilities._luigi.common import (
     TimeParameter,
     WeekdayParameter,
 )
-from utilities.class_name import get_class_name
 from utilities.dataclasses import Dataclass
 from utilities.errors import redirect_error
+from utilities.types import get_class_name
 
 _T = TypeVar("_T", bound=Dataclass)
 
@@ -165,8 +165,8 @@ def annotation_date_to_class(
             return DateParameter
         case "weekday":
             return WeekdayParameter
-        case _:  # pragma: no cover  # type: ignore
-            assert_never(kind)
+        case _ as never:  # type: ignore
+            assert_never(never)
 
 
 def annotation_datetime_to_class(
@@ -180,8 +180,8 @@ def annotation_datetime_to_class(
             cls = DateMinuteParameter
         case "second":
             cls = DateSecondParameter
-        case _:  # pragma: no cover  # type: ignore
-            assert_never(kind)
+        case _ as never:  # type: ignore
+            assert_never(never)
     return partial(cls, interval=interval)
 
 
