@@ -3,7 +3,6 @@ from __future__ import annotations
 from collections.abc import Callable, Iterator, Mapping, Sequence
 from contextlib import contextmanager
 from functools import partial
-from pathlib import Path
 from typing import Any, Literal, cast
 
 from numpy import array, datetime64, isin, ndarray, prod
@@ -14,7 +13,6 @@ from zarr.convenience import open_group
 from zarr.core import Attributes
 
 from utilities.atomicwrites import writer
-from utilities.class_name import get_class_name
 from utilities.datetime import ensure_date, ensure_datetime
 from utilities.errors import redirect_error
 from utilities.iterables import is_iterable_not_str
@@ -30,10 +28,10 @@ from utilities.numpy import (
     get_fill_value,
     has_dtype,
 )
-from utilities.pathlib import PathLike
+from utilities.pathvalidate import valid_path
 from utilities.re import extract_group
 from utilities.sentinel import Sentinel, sentinel
-from utilities.types import is_sized_not_str
+from utilities.types import PathLike, get_class_name, is_sized_not_str
 
 IselIndexer = int | slice | Sequence[int] | NDArrayB1 | NDArrayI1
 
@@ -118,7 +116,7 @@ class NDArrayWithIndexes:
         self, path: PathLike, /, *, mode: Literal["r", "r+", "a", "w", "w-"] = "a"
     ) -> None:
         super().__init__()
-        self._path = Path(path)
+        self._path = valid_path(path)
         if not self._path.exists():
             msg = f"{self._path}"
             raise FileNotFoundError(msg)
@@ -126,13 +124,11 @@ class NDArrayWithIndexes:
 
     @override
     def __repr__(self) -> str:
-        cls = get_class_name(self)
-        return f"{cls}({self._path})"
+        return "{}({})".format(get_class_name(self), self._path)
 
     @override
     def __str__(self) -> str:
-        cls = get_class_name(self)
-        return f"{cls}({self._path})"
+        return "{}({})".format(get_class_name(self), self._path)
 
     @property
     def array(self) -> Array:
