@@ -1,10 +1,12 @@
+from __future__ import annotations
+
 import re
 from collections.abc import Callable
 from typing import Any
 
-from beartype import beartype
 from fastapi import APIRouter as _APIRouter
 from fastapi.types import DecoratedCallable
+from typing_extensions import override
 
 _PATTERN = re.compile(r"(^/$)|(^.+[^\/]$)")
 
@@ -12,8 +14,8 @@ _PATTERN = re.compile(r"(^/$)|(^.+[^\/]$)")
 class APIRouter(_APIRouter):
     """Subclass which handles paths with & without trailing slashes."""
 
-    @beartype
-    def api_route(
+    @override
+    def api_route(  # type: ignore
         self, *, path: str, include_in_schema: bool = True, **kwargs: Any
     ) -> Callable[[DecoratedCallable], DecoratedCallable]:
         """N/A."""
@@ -23,3 +25,6 @@ class APIRouter(_APIRouter):
             )
         msg = f"Invalid route: {path}"
         raise ValueError(msg)
+
+
+__all__ = ["APIRouter"]
