@@ -8,9 +8,9 @@ from typing import Any
 
 from utilities.atomicwrites import writer
 from utilities.datetime import UTC, duration_to_float, get_now
-from utilities.git import get_repo_root
+from utilities.git import valid_path_repo
 from utilities.hashlib import md5_hash
-from utilities.pathlib import PathLike
+from utilities.pathvalidate import valid_path
 from utilities.platform import (
     IS_LINUX,
     IS_MAC,
@@ -19,7 +19,7 @@ from utilities.platform import (
     IS_NOT_WINDOWS,
     IS_WINDOWS,
 )
-from utilities.types import Duration, IterableStrs
+from utilities.types import Duration, IterableStrs, PathLike
 
 try:  # WARNING: this package cannot use unguarded `pytest` imports
     from _pytest.config import Config
@@ -37,7 +37,7 @@ except ModuleNotFoundError:  # pragma: no cover
         skipif_windows
     ) = (
         skipif_mac
-    ) = skipif_linux = skipif_not_windows = skipif_not_mac = skipif_linux = None
+    ) = skipif_linux = skipif_not_windows = skipif_not_mac = skipif_not_linux = None
 else:
     skipif_windows = mark.skipif(IS_WINDOWS, reason="Skipped for Windows")
     skipif_mac = mark.skipif(IS_MAC, reason="Skipped for Mac")
@@ -97,20 +97,15 @@ def add_pytest_configure(config: Config, options: Iterable[tuple[str, str]], /)
         _ = config.addinivalue_line("markers", f"{opt}: mark test as {desc}")
 
 
-def is_pytest() -> bool:
-    """Check if pytest is currently running."""
-    return "PYTEST_CURRENT_TEST" in environ
-
-
 def throttle(
-    *, root: PathLike | None = None, duration: Duration = 1.0, on_pass: bool = False
+    *, root: PathLike | None = None, duration: Duration = 1.0, on_try: bool = False
 ) -> Any:
-    """Throttle a test. On run by default, by pass otherwise."""
+    """Throttle a test. On success by default, on try otherwise."""
 
     if root is None:
-        root_use = get_repo_root().joinpath(".pytest_cache", "throttle")
+        root_use = valid_path_repo(".pytest_cache", "throttle")
     else:
-        root_use = Path(root)
+        root_use = valid_path(root)
 
     def wrapper(func: Callable[..., Any], /) -> Callable[..., Any]:
         """Decorator to throttle a test function/method."""
@@ -119,7 +114,7 @@ def throttle(
         def wrapped(*args: Any, **kwargs: Any) -> Any:
             """The throttled test function/method."""
             test = environ["PYTEST_CURRENT_TEST"]
-            if (path := root_use.joinpath(_throttle_md5_hash(test))).exists():
+            if (path := valid_path(root_use, _throttle_md5_hash(test))).exists():
                 with path.open(mode="r") as fh:
                     contents = fh.read()
                 prev = float(contents)
@@ -132,12 +127,12 @@ def throttle(
                 and ((now - prev) < duration_to_float(duration))
             ):
                 skip(reason=f"{test} throttled")
-            if on_pass:
-                out = func(*args, **kwargs)
+            if on_try:
                 _throttle_write(path, now)
-                return out
+                return func(*args, **kwargs)
+            out = func(*args, **kwargs)
             _throttle_write(path, now)
-            return func(*args, **kwargs)
+            return out
 
         return wrapped
 
@@ -158,7 +153,6 @@ __all__ = [
     "add_pytest_addoption",
     "add_pytest_collection_modifyitems",
     "add_pytest_configure",
-    "is_pytest",
     "skipif_linux",
     "skipif_mac",
     "skipif_not_linux",
