@@ -1,13 +1,13 @@
+from __future__ import annotations
+
 from collections.abc import Iterator
 from contextlib import contextmanager
 from os import getenv
 
-from beartype import beartype
 from pytest_check import check as _check
 
 
 @contextmanager
-@beartype
 def check() -> Iterator[None]:
     """Context manager running `pytest_check`, but can be disabled."""
     if getenv("PYTEST_CHECK") == "0":
@@ -15,3 +15,6 @@ def check() -> Iterator[None]:
     else:
         with _check():
             yield
+
+
+__all__ = ["check"]
