@@ -3,6 +3,7 @@ from __future__ import annotations
 from dataclasses import dataclass
 from pathlib import Path
 
+from utilities.pathvalidate import valid_path
 from utilities.typed_settings import click_field
 
 
@@ -10,4 +11,6 @@ from utilities.typed_settings import click_field
 class Config:
     """Settings for the `monitor_memory` script."""
 
-    path: Path = click_field(default=Path("input.csv"), param_decls=("-p", "--path"))
+    path: Path = click_field(
+        default=valid_path("input.csv"), param_decls=("-p", "--path")
+    )
