@@ -6,10 +6,10 @@ from click import command
 from loguru import logger
 
 from utilities.loguru import setup_loguru
-from utilities.pathlib import PathLike
 from utilities.scripts.luigi_server.classes import Config
 from utilities.subprocess import run_accept_address_in_use
 from utilities.typed_settings import click_options
+from utilities.types import PathLike
 
 _CONFIG = Config()
 
