@@ -35,4 +35,4 @@ class Sentinel(metaclass=_Meta):
 sentinel = Sentinel()
 
 
-__all__ = ["sentinel", "Sentinel"]
+__all__ = ["Sentinel", "sentinel"]
