@@ -51,13 +51,12 @@ from utilities._sqlalchemy.common import (
     is_table_or_mapped_class,
     mapped_class_to_dict,
 )
-from utilities.class_name import get_class_name
 from utilities.errors import redirect_error
 from utilities.humps import snake_case, snake_case_mappings
 from utilities.iterables import CheckLengthError, check_length
 from utilities.math import FloatFinNonNeg, IntNonNeg
 from utilities.text import ensure_str
-from utilities.types import IterableStrs
+from utilities.types import IterableStrs, get_class_name
 
 
 def _check_column_collections_equal(
@@ -307,15 +306,15 @@ def check_engine(
     Optionally query for the number of tables, or the number of columns in
     such a table.
     """
-    match dialect := get_dialect(engine):
+    match get_dialect(engine):
         case Dialect.mssql | Dialect.mysql | Dialect.postgresql:  # pragma: no cover
             query = "select * from information_schema.tables"
         case Dialect.oracle:  # pragma: no cover
             query = "select * from all_objects"
         case Dialect.sqlite:
             query = "select * from sqlite_master where type='table'"
-        case _:  # pragma: no cover  # type: ignore
-            assert_never(dialect)
+        case _ as never:  # type: ignore
+            assert_never(never)
     statement = text(query)
     with engine.begin() as conn:
         rows = conn.execute(statement).all()
@@ -510,8 +509,8 @@ def redirect_table_does_not_exist(engine: Engine, /) -> Iterator[None]:
             match = "ORA-00942: table or view does not exist"
         case Dialect.sqlite:
             match = "no such table"
-        case _:  # pragma: no cover  # type: ignore
-            assert_never(dialect)
+        case _ as never:  # type: ignore
+            assert_never(never)
     with redirect_error(DatabaseError, TableDoesNotExistError, match=match):
         yield
 
@@ -544,17 +543,22 @@ class TablenameMixin:
 
     @cast(Any, declared_attr)
     def __tablename__(cls) -> str:  # noqa: N805
-        return get_class_name(cls, snake=True)
+        return snake_case(get_class_name(cls))
 
 
 __all__ = [
+    "CHUNK_SIZE_FRAC",
+    "CheckEngineError",
+    "Dialect",
+    "GetDialectError",
+    "GetTableError",
+    "ParseEngineError",
+    "TablenameMixin",
     "check_engine",
     "check_table_against_reflection",
-    "CheckEngineError",
     "columnwise_max",
     "columnwise_min",
     "create_engine",
-    "Dialect",
     "ensure_engine",
     "ensure_tables_created",
     "ensure_tables_dropped",
@@ -562,20 +566,15 @@ __all__ = [
     "get_column_names",
     "get_columns",
     "get_dialect",
-    "get_table_name",
     "get_table",
-    "GetDialectError",
-    "GetTableError",
-    "CHUNK_SIZE_FRAC",
+    "get_table_name",
     "insert_items",
     "is_mapped_class",
     "is_table_or_mapped_class",
     "mapped_class_to_dict",
     "parse_engine",
-    "ParseEngineError",
     "redirect_table_does_not_exist",
     "serialize_engine",
-    "TablenameMixin",
 ]
 
 
@@ -606,7 +605,7 @@ except ModuleNotFoundError:  # pragma: no cover
     pass
 else:
     __all__ += [
-        "next_from_sequence",
         "NextFromSequenceError",
+        "next_from_sequence",
         "redirect_next_from_sequence_error",
     ]
