@@ -3,7 +3,7 @@ from __future__ import annotations
 import datetime as dt
 import enum
 from collections.abc import Callable, Iterable, Mapping
-from dataclasses import MISSING, field
+from dataclasses import MISSING, dataclass, field
 from itertools import starmap
 from operator import attrgetter, itemgetter
 from pathlib import Path
@@ -26,6 +26,7 @@ from typed_settings.constants import CLICK_METADATA_KEY, METADATA_KEY
 from typed_settings.converters import TSConverter
 from typed_settings.loaders import Loader
 from typed_settings.types import AUTO, _Auto
+from typing_extensions import override
 
 import utilities.click
 from utilities.click import Date, DateTime, Time, Timedelta
@@ -38,13 +39,14 @@ from utilities.datetime import (
     serialize_time,
 )
 from utilities.git import get_repo_root_or_cwd_sub_path
-from utilities.pathlib import PathLike
+from utilities.pathvalidate import valid_path
+from utilities.types import PathLike, ensure_class
 
 _T = TypeVar("_T")
 
 
 def _config_toml(root: Path, /) -> Path | None:
-    return path if (path := root.joinpath("config.toml")).exists() else None
+    return path if (path := valid_path(root, "config.toml")).exists() else None
 
 
 _CONFIG_FILES = [
@@ -84,10 +86,7 @@ def _pair_type_and_converter(
     cls: type[Any], func: Callable[[Any], Any], /
 ) -> Callable[[Any, type[Any]], Any]:
     def hook(value: Any, _: type[Any] = Any, /) -> Any:
-        if not isinstance(value, cls | str):
-            msg = f"Could not convert value to {cls.__name__}: {value}"
-            raise TypeError(msg)
-        return func(value)
+        return func(ensure_class(value, (cls, str)))
 
     return hook
 
@@ -101,8 +100,7 @@ def _get_loaders(
     env_prefix: None | str | _Auto = AUTO,
 ) -> list[Loader]:
     if search("_", appname):
-        msg = f"{appname=}"
-        raise _GetLoadersError(msg)
+        raise _GetLoadersError(appname=appname)
     return default_loaders(
         appname,
         config_files=config_files,
@@ -112,8 +110,13 @@ def _get_loaders(
     )
 
 
+@dataclass(frozen=True, kw_only=True, slots=True)
 class _GetLoadersError(Exception):
-    ...
+    appname: str
+
+    @override
+    def __str__(self) -> str:
+        return "App name {!r} must not contain underscores".format(self.appname)
 
 
 def load_settings(
