@@ -1,10 +1,11 @@
 from __future__ import annotations
 
 import datetime as dt
+from dataclasses import dataclass
 from datetime import tzinfo
 from typing import Literal
 
-from typing_extensions import assert_never
+from typing_extensions import override
 from xlrd import Book, xldate_as_datetime
 
 from utilities.datetime import UTC
@@ -17,15 +18,21 @@ def get_date_mode() -> Literal[0, 1]:
             return 0
         case System.mac:  # pragma: os-ne-macos
             return 1
-        case System.linux:  # pragma: no cover
-            msg = f"{SYSTEM=}"
-            raise GetDateModeError(msg)
-        case _:  # pragma: no cover  # type: ignore
-            assert_never(SYSTEM)
+        case system:  # pragma: no cover
+            raise GetDateModeError(system=system)
 
 
+@dataclass(frozen=True, kw_only=True, slots=True)
 class GetDateModeError(Exception):
-    ...
+    system: System
+
+    @override
+    def __str__(self) -> str:
+        return (  # pragma: no cover
+            "System must be one of Windows or Darwin; got {} instead".format(
+                self.system
+            )
+        )
 
 
 def to_date(
@@ -43,4 +50,4 @@ def to_datetime(
     return xldate_as_datetime(date, date_mode).replace(tzinfo=tzinfo)  # os-eq-linux
 
 
-__all__ = ["get_date_mode", "GetDateModeError", "to_date", "to_datetime"]
+__all__ = ["GetDateModeError", "get_date_mode", "to_date", "to_datetime"]
